@@ -1,7 +1,7 @@
 // qsynthOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -535,9 +535,11 @@ void qsynthOptions::loadSetup ( qsynthSetup *pSetup, const QString& sName )
 	pSetup->iAudioBufCount   = m_settings.value("/AudioBufCount", 2).toInt();
 #endif
 	pSetup->sMidiName        = m_settings.value("/AlsaName", "pid").toString();
+	pSetup->bMidiAutoConnect = m_settings.value("/MidiAutoConnect", true).toBool();
 	pSetup->sJackName        = m_settings.value("/JackName", "qsynth").toString();
 	pSetup->bJackAutoConnect = m_settings.value("/JackAutoConnect", true).toBool();
 	pSetup->bJackMulti       = m_settings.value("/JackMulti", false).toBool();
+	pSetup->bWasapiExclusive = m_settings.value("/WasapiExclusive", false).toBool();
 #if defined(__OpenBSD__)
 	pSetup->sMidiDevice      = m_settings.value("/MidiDevice", "midithru/0").toString();
 #else
@@ -655,12 +657,14 @@ void qsynthOptions::saveSetup ( qsynthSetup *pSetup, const QString& sName )
 	m_settings.setValue("/MidiDevice",       pSetup->sMidiDevice);
 	m_settings.setValue("/MidiChannels",     pSetup->iMidiChannels);
 	m_settings.setValue("/AlsaName",         pSetup->sMidiName);
+	m_settings.setValue("/MidiAutoConnect",  pSetup->bMidiAutoConnect);
 	m_settings.setValue("/MidiBankSelect",   pSetup->sMidiBankSelect);
 	m_settings.setValue("/AudioDriver",      pSetup->sAudioDriver);
 	m_settings.setValue("/AudioDevice",      pSetup->sAudioDevice);
 	m_settings.setValue("/JackName",         pSetup->sJackName);
 	m_settings.setValue("/JackAutoConnect",  pSetup->bJackAutoConnect);
 	m_settings.setValue("/JackMulti",        pSetup->bJackMulti);
+	m_settings.setValue("/WasapiExclusive",  pSetup->bWasapiExclusive);
 	m_settings.setValue("/AudioChannels",    pSetup->iAudioChannels);
 	m_settings.setValue("/AudioGroups",      pSetup->iAudioGroups);
 	m_settings.setValue("/AudioBufSize",     pSetup->iAudioBufSize);
